@@ -286,7 +286,13 @@ impl TbsCertificate {
 
         let captured = cons.capture(|cons| {
             cons.take_sequence(|cons| {
-                let version = cons.take_constructed_if(Tag::CTX_0, Version::take_from)?;
+                let version = if let Some(version) =
+                    cons.take_opt_constructed_if(Tag::CTX_0, Version::take_from)?
+                {
+                    version
+                } else {
+                    Version::V1
+                };
                 let serial_number = CertificateSerialNumber::take_from(cons)?;
                 let signature = AlgorithmIdentifier::take_from(cons)?;
                 let issuer = Name::take_from(cons)?;
